@@ -197,7 +197,7 @@ connect_object_to_session (OobsObject *object)
 
   if (!connection)
     {
-      g_critical ("OobsSession object hasn't connected to the bus, cannot register OobsObject");
+      g_warning ("OobsSession object hasn't connected to the bus, cannot register OobsObject");
       return;
     }
 
@@ -316,11 +316,14 @@ run_message (OobsObject  *object,
   DBusMessage       *reply;
 
   priv = object->_priv;
+
+  if (!oobs_session_get_connected (priv->session))
+    {
+      g_warning ("could send message, OobsSession hasn't connected to the bus");
+      return NULL;
+    }
+
   connection = _oobs_session_get_connection_bus (priv->session);
-
-  g_return_val_if_fail (oobs_session_get_connected (priv->session), NULL);
-  g_return_val_if_fail (connection != NULL, NULL);
-
   reply = dbus_connection_send_with_reply_and_block (connection, message, -1, &priv->dbus_error);
 
   if (dbus_error_is_set (&priv->dbus_error))
@@ -328,7 +331,7 @@ run_message (OobsObject  *object,
       if (dbus_error_has_name (&priv->dbus_error, DBUS_ERROR_ACCESS_DENIED))
 	*result = OOBS_RESULT_ACCESS_DENIED;
       else
-	g_critical ("There was an unknown error communicating with the backends: %s", priv->dbus_error.message);
+	g_warning ("There was an unknown error communicating with the backends: %s", priv->dbus_error.message);
 
       dbus_error_free (&priv->dbus_error);
       return NULL;
@@ -395,11 +398,14 @@ run_message_async (OobsObject          *object,
   DBusConnection *connection;
 
   priv = object->_priv;
+
+  if (!oobs_session_get_connected (priv->session))
+    {
+      g_warning ("could not send message, OobsSession hasn't connected to the bus");
+      return;
+    }
+
   connection = _oobs_session_get_connection_bus (priv->session);
-
-  g_return_if_fail (oobs_session_get_connected (priv->session));
-  g_return_if_fail (connection != NULL);
-
   dbus_connection_send_with_reply (connection, message, &call, -1);
 
   async_data = g_new0 (OobsObjectAsyncCallbackData, 1);
@@ -559,7 +565,7 @@ oobs_object_update (OobsObject *object)
       result = update_object_from_message (object, reply);
       dbus_message_unref (reply);
     }
-      
+
   dbus_message_unref (message);
   return result;
 }
